summaryrefslogtreecommitdiffstats
path: root/chromium/content/common/appcache_messages.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/content/common/appcache_messages.h')
-rw-r--r--chromium/content/common/appcache_messages.h26
1 files changed, 19 insertions, 7 deletions
diff --git a/chromium/content/common/appcache_messages.h b/chromium/content/common/appcache_messages.h
index 185caf46580..8ad8fd5a5d7 100644
--- a/chromium/content/common/appcache_messages.h
+++ b/chromium/content/common/appcache_messages.h
@@ -9,8 +9,12 @@
#define IPC_MESSAGE_START AppCacheMsgStart
-IPC_ENUM_TRAITS(appcache::EventID)
-IPC_ENUM_TRAITS(appcache::Status)
+IPC_ENUM_TRAITS_MAX_VALUE(appcache::AppCacheEventID,
+ appcache::APPCACHE_EVENT_ID_LAST)
+IPC_ENUM_TRAITS_MAX_VALUE(appcache::AppCacheStatus,
+ appcache::APPCACHE_STATUS_LAST)
+IPC_ENUM_TRAITS_MAX_VALUE(appcache::AppCacheErrorReason,
+ appcache::APPCACHE_ERROR_REASON_LAST)
IPC_STRUCT_TRAITS_BEGIN(appcache::AppCacheInfo)
IPC_STRUCT_TRAITS_MEMBER(manifest_url)
@@ -34,6 +38,14 @@ IPC_STRUCT_TRAITS_BEGIN(appcache::AppCacheResourceInfo)
IPC_STRUCT_TRAITS_MEMBER(is_explicit)
IPC_STRUCT_TRAITS_END()
+IPC_STRUCT_TRAITS_BEGIN(appcache::AppCacheErrorDetails)
+IPC_STRUCT_TRAITS_MEMBER(message)
+IPC_STRUCT_TRAITS_MEMBER(reason)
+IPC_STRUCT_TRAITS_MEMBER(url)
+IPC_STRUCT_TRAITS_MEMBER(status)
+IPC_STRUCT_TRAITS_MEMBER(is_cross_origin)
+IPC_STRUCT_TRAITS_END()
+
// AppCache messages sent from the child process to the browser.
// Informs the browser of a new appcache host.
@@ -58,7 +70,7 @@ IPC_MESSAGE_CONTROL2(AppCacheHostMsg_SetSpawningHostId,
// 'host_id' indentifies a specific document or worker
// 'document_url' the url of the main resource
// 'appcache_document_was_loaded_from' the id of the appcache the main
// resource was loaded from or kNoCacheId
// 'opt_manifest_url' the manifest url specified in the <html> tag if any
IPC_MESSAGE_CONTROL4(AppCacheHostMsg_SelectCache,
int /* host_id */,
@@ -84,7 +96,7 @@ IPC_MESSAGE_CONTROL3(AppCacheHostMsg_MarkAsForeignEntry,
// Returns the status of the appcache associated with host_id.
IPC_SYNC_MESSAGE_CONTROL1_1(AppCacheHostMsg_GetStatus,
int /* host_id */,
- appcache::Status)
+ appcache::AppCacheStatus)
// Initiates an update of the appcache associated with host_id.
IPC_SYNC_MESSAGE_CONTROL1_1(AppCacheHostMsg_StartUpdate,
@@ -114,13 +126,13 @@ IPC_MESSAGE_CONTROL2(AppCacheMsg_CacheSelected,
// Notifies the renderer of an AppCache status change.
IPC_MESSAGE_CONTROL2(AppCacheMsg_StatusChanged,
std::vector<int> /* host_ids */,
- appcache::Status)
+ appcache::AppCacheStatus)
// Notifies the renderer of an AppCache event other than the
// progress event which has a seperate message.
IPC_MESSAGE_CONTROL2(AppCacheMsg_EventRaised,
std::vector<int> /* host_ids */,
- appcache::EventID)
+ appcache::AppCacheEventID)
// Notifies the renderer of an AppCache progress event.
IPC_MESSAGE_CONTROL4(AppCacheMsg_ProgressEventRaised,
@@ -132,7 +144,7 @@ IPC_MESSAGE_CONTROL4(AppCacheMsg_ProgressEventRaised,
// Notifies the renderer of an AppCache error event.
IPC_MESSAGE_CONTROL2(AppCacheMsg_ErrorEventRaised,
std::vector<int> /* host_ids */,
- std::string /* error_message */)
+ appcache::AppCacheErrorDetails)
// Notifies the renderer of an AppCache logging message.
IPC_MESSAGE_CONTROL3(AppCacheMsg_LogMessage,
@@ -58,7 +70,7 @@ IPC_MESSAGE_CONTROL2(AppCacheHostMsg_SetSpawningHostId,
// 'document_url' the url of the main resource
// 'appcache_document_was_loaded_from' the id of the appcache the main
-// resource was loaded from or kNoCacheId
+// resource was loaded from or kAppCacheNoCacheId
// 'opt_manifest_url' the manifest url specified in the <html> tag if any
IPC_MESSAGE_CONTROL4(AppCacheHostMsg_SelectCache,